@@ -55,8 +55,8 @@ char		*extens[] = {
 		 all_extensions[] =
 			"\\.jpg\\|\\.jpeg\\|\\.png\\|\\.gif\\|"
 			"\\.JPG\\|\\.JPEG\\|\\.PNG\\|\\.GIF";
-int		 nr_extensions = 8,
-		 ext_nr = 0;
+#define		 nr_extensions  (sizeof(extens)/sizeof(char *))
+int		 ext_nr = 0;
 gboolean	 file_list_expanded = FALSE;
 
 
@@ -286,18 +286,19 @@ start_show(void)
   g_file_get_contents(tmpf, &bff, NULL, NULL);
   names = g_strsplit(bff, "\n", 0);
   
+  // Scan through the file list obtained above
   for (s = 0; names[s] != NULL; s++) {
-    if (strlen(names[s]) == 0) continue;
+    if (strlen(names[s]) == 0) continue;	// Skip empty lines
 
-    for (t = 0; t < nr_extensions; t++)
+    for (t = 0; t < nr_extensions; t++)		// Check for valid extensions
       if ((p = strstr(names[s]+bffbeg, extens[t])) != NULL) break;
 
-    if (t == nr_extensions) {		// then we don't know how to handle
-      printf(_("Cannot find a suitable extension.\n"));
+    if (t == nr_extensions) {			// then we don't know how to handle
+      printf(_("Cannot find a known image extension.\n"));
       exit(1);
     }
 
-    if (p == NULL) continue;		// is any valid extension present?
+    if (p == NULL) continue;			// is any valid extension present?
     p = strdup(names[s]+bffbeg);
     pagelist = g_list_append(pagelist, p);
   }
@@ -421,8 +422,9 @@ show_page(int nr)
     return;
   }
 
-  bff = g_strdup_printf(_("CBR Pager - %s"),
-			(char *)g_list_nth_data(pagelist, nr));
+  bff = g_strdup_printf(_("CBR Pager - %s (%d/%d)"),
+			(char *)g_list_nth_data(pagelist, nr),
+			nr+1, g_list_length(pagelist));
   gtk_window_set_title(GTK_WINDOW(MainWindow), bff);
   g_free(bff);
 
@@ -733,11 +735,20 @@ void
 main_canvas_buttonpressed(GdkEventButton *event)
 {
   GtkWidget *w;
+  char *wdg;
   
   if (event->type != GDK_BUTTON_PRESS) return;
   
   switch (event->button) {
     case 1:				// Left button
+        wdg = "next_btn";               
+        w = lookup_widget(nav_window, wdg);
+        g_signal_emit_by_name(w, "clicked", NULL);
+        break;
+    case 2:				// Middle button
+        wdg = "back_btn";               
+        w = lookup_widget(nav_window, wdg);
+        g_signal_emit_by_name(w, "clicked", NULL);
         break;
     case 3:
         w = create_help_popup();
