@@ -31,6 +31,7 @@ void		next_page(int adv);
 void		previous_page(int prv);
 void		goto_begin(void);
 void		goto_end(void);
+void		file_list_tbtn_clicked(void);
 
 void		update_nav_position(void);
 void		install_timer(void);
@@ -40,5 +41,6 @@ void		main_canvas_buttonpressed(GdkEventButton  *event);
 
 void		set_zoom_factor(double factor);
 void		set_zoom_fit(void);
+void		set_zoom_width(void);
 void		fit_page(int w, int h);
 void		fit_width(int w);
